--[[
Copyright © 2021, Sjshovan (LoTekkie)
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    * Neither the name of Yield nor the
      names of its contributors may be used to endorse or promote products
      derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL Sjshovan (LoTekkie) BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
--]]

-- Template for Yield metrics.
metricsTemplate =
{
    totals =
    {
        lost     = 0,
        yields   = 0,
        breaks   = 0,
        attempts = 0
    },
    secondsPassed  = 0,
    estimatedValue = 0,
    yields         = {},
    points =
    {
        yields = {0},
        values = {0}
    }
}

-- Template for Yield state.
stateTemplate =
{
    window        = {},
    initializing  = true,
    firstLoad     = true,
    reportsLoaded = false,
    attempting    = false,
    attemptType   = "harvesting",
    gathering     = "harvesting",
    settings =
    {
        activeIndex = 1,
        setPrices   = { gathering = "harvesting" },
        setColors   = { gathering = "harvesting" },
        setAlerts   = { gathering = "harvesting" },
        reports     = { gathering = "harvesting" },
        alerts      = { gathering = "harvesting" }
    },
    help =
    {
        activeIndex = 1,
    },
    timers = {},
    values =
    {
        btnStartTimer        = "Start",
        modalConfirmPrompt   = "Are you sure?",
        modalConfirmHelp     = "",
        modalConfirmDanger   = false,
        yieldsLabelIndex     = 1, -- Full
        valuesLabelIndex     = 1, -- Full
        yieldSortIndex       = 3, -- Count (DESC)
        yieldListBtnsHovered = false,
        yieldListHovered     = false,
        yieldListClicked     = false,
        inactivitySeconds    = 0,
        btnTextureFailure    = false,
        targetAlertReady     = false,
        feedbackSubmitted    = false,
        feedbackMissing      = false,
        zoning               = false,
        preZoneCounts        = {},
        settingsWindowOpen   = false,
        helpWindowOpen       = false,
        lastKnownGathering   = nil,
        currentReportName    = nil,
        genReportDisabled    = false,
        clamBucketBroken     = false,
        clamConfirmedYields  = {},
        clamBucketTotal      = 0,
        clamBucketPz         = 0,
        centerWindow         = false,
    },
    actions =
    {
        modalConfirmAction = function() end,
        modalCancelAction  = function() end
    }
}

-- Template for Yield settings.
defaultSettingsTemplate =
{
    general =
    {
        opacity               = 1.0,
        targetValue           = 0,
        showToolTips          = true,
        windowScaleIndex      = 0,
        showDetailedYields    = true,
        yieldDetailsColor     = -3877684,
        useImageButtons       = true,
        enableSoundAlerts     = true,
        targetSoundFile       = "",
        autoGenReports        = true,
        fishingSkillSoundFile = "",
        clamBreakSoundFile    = "",
    },
    state =
    {
        gathering          = "harvesting",
        lastKnownGathering = nil,
        windowPosX         = 0,
        windowPosY         = 0,
        clamBucketBroken   = false,
        clamBucketTotal    = 0,
        clamBucketPz       = 0,
        clamBucketPzMax    = 50,
        firstLoad          = true,
    },
    priceModes = -- 0 - stack price, 1 - single price, 2 - npc price.
    {
        harvesting = 0,
        excavating = 0,
        logging    = 0,
        mining     = 0,
        clamming   = 0,
        fishing    = 0,
        digging    = 0
    },
    zones = -- capture zoneIds when gathering for report generation.
    {
        harvesting = {},
        excavating = {},
        logging    = {},
        mining     = {},
        clamming   = {},
        fishing    = {},
        digging    = {}
    },
    yields =
    {
        harvesting = 
        {
            ["Mohbwa Grass"]           = { id = 2295, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Fresh Marjoram"]         = { id = 1522, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Pephredo Hive Chip"]     = { id = 2164, short = "Pep. Hive Chip", singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Simsim"]                 = { id = 2236, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Imperial Tea Leaves"]    = { id = 2156, short = "Imp. Tea Leaves", singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Coffee Cherries"]        = { id = 2270, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Eggplant"]               = { id = 4388, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Red Moko Grass"]         = { id = 1845, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Fresh Mugwort"]          = { id = 1524, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Wijnruit"]               = { id = 951, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Eastern Ginger"]         = { id = 2645, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Moko Grass"]             = { id = 833, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Saruta Cotton"]          = { id = 834, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Flax Flower"]            = { id = 835, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Dyer's Woad"]            = { id = 2713, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Gysahl Greens"]          = { id = 4545, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Windurstian Tea Leaves"] = { id = 635, short = "Win. Tea Leaves", singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Skull Locust"]           = { id = 1981, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Vegetable Seeds"]        = { id = 573, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Herb Seeds"]             = { id = 572, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Grain Seeds"]            = { id = 575, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Crawler Cocoon"]         = { id = 839, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["King Locust"]            = { id = 1982, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Burdock"]                = { id = 5651, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Lesser Chigoe"]          = { id = 2155, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Winterflower"]           = { id = 5907, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Woozyshroom"]            = { id = 4373, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Danceshroom"]            = { id = 4375, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Sleepshroom"]            = { id = 4374, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Scream Fungus"]          = { id = 4447, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Coral Fungus"]           = { id = 4450, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Reishi Mushroom"]        = { id = 4449, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Mushroom Locust"]        = { id = 1983, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Grauberg Greens"]        = { id = 5444, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Puffball"]               = { id = 4448, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["King Truffle"]           = { id = 4386, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
        },
        excavating =
        {
            ["Bone Chip"]                   = { id = 880, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Chicken Bone"]                = { id = 898, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Giant Femur"]                 = { id = 893, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Little Worm"]                 = { id = 17396, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 99, color = -3877684, soundFile = "" },
            ["Bat Fang"]                    = { id = 891, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Scorpion Claw"]               = { id = 897, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Scorpion Shell"]              = { id = 896, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Turtle Shell"]                = { id = 885, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Silica"]                      = { id = 1888, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Red Rock"]                    = { id = 769, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Yellow Rock"]                 = { id = 771, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Blue Rock"]                   = { id = 770, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Green Rock"]                  = { id = 772, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Translucent Rock"]            = { id = 773, short = "Trans. Rock", singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Purple Rock"]                 = { id = 774, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["White Rock"]                  = { id = 776, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Black Rock"]                  = { id = 775, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Rock Salt"]                   = { id = 936, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Seashell"]                    = { id = 888, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Shell Bug"]                   = { id = 17397, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Fish Scales"]                 = { id = 864, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Lugworm"]                     = { id = 17395, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 99, color = -3877684, soundFile = "" },
            ["Crab Shell"]                  = { id = 881, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Helmet Mole"]                 = { id = 1985, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Coral Fragment"]              = { id = 887, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Petrified Log"]               = { id = 703, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Antlion Jaw"]                 = { id = 2503, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Cactus Stems"]                = { id = 1236, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Almonds"]                     = { id = 2503, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["High-Quality Scorpion Shell"] = { id = 1473, short = "HQ Scorpion Shell", singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },

        },
        logging =
        {
            ["Lauan Log"]         = { id = 689, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Arrowwood Log"]     = { id = 688, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Yagudo Cherry"]     = { id = 4445, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Buburimu Grape"]    = { id = 4503, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Dryad Root"]        = { id = 923, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Fruit Seeds"]       = { id = 574, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Holly Log"]         = { id = 697, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Ebony Log"]         = { id = 702, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Mahogany Log"]      = { id = 700, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Rosewood Log"]      = { id = 701, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Ash Log"]           = { id = 698, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Maple Log"]         = { id = 691, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Willow Log"]        = { id = 695, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Elm Log"]           = { id = 690, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Acorn"]             = { id = 4504, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Walnut Log"]        = { id = 693, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Oak Log"]           = { id = 699, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Yew Log"]           = { id = 696, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Faerie Apple"]      = { id = 4363, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Pine Nuts"]         = { id = 2213, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Almonds"]           = { id = 2503, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Date"]              = { id = 5566, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Chestnut Log"]      = { id = 694, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Bloodwood Log"]     = { id = 729, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Walnut"]            = { id = 5661, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Ronfaure Chestnut"] = { id = 639, short = "Ron. Chestnut", singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Jacaranda Log"]     = { id = 2534, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Teak Log"]          = { id = 2532, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Rattan Lumber"]     = { id = 721, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Revival Root"]      = { id = 940, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Aquilaria Log"]     = { id = 731, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Beehive Chip"]      = { id = 912, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Tree Cuttings"]     = { id = 1237, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Dragon Fruit"]      = { id = 5662, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Holy Water"]        = { id = 4154, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Nopales"]           = { id = 5650, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Bird Feather"]      = { id = 847, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Bird Egg"]          = { id = 4570, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Cactus Stems"]      = { id = 1236, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Butterpear"]        = { id = 5908, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Kapor Log"]         = { id = 732, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
        },
        mining =
        {
            ["Copper Ore"]       = { id = 640, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Zinc Ore"]         = { id = 642, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Tin Ore"]          = { id = 641, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Iron Ore"]         = { id = 643, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Silver Ore"]       = { id = 736, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Darksteel Ore"]    = { id = 645, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Gold Ore"]         = { id = 737, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Mythril Ore"]      = { id = 644, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Platinum Ore"]     = { id = 738, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Aluminum Ore"]     = { id = 678, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Adaman Ore"]       = { id = 646, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Khroma Ore"]       = { id = 685, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Luminium Ore"]     = { id = 2228, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Orichalcum Ore"]   = { id = 739, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Pebble"]           = { id = 17296, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 99, color = -3877684, soundFile = "" },
            ["Flint Stone"]      = { id = 768, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Igneous Rock"]     = { id = 1654, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Red Rock"]         = { id = 769, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Yellow Rock"]      = { id = 771, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Blue Rock"]        = { id = 770, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Green Rock"]       = { id = 772, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Translucent Rock"] = { id = 773, short = "Trans. Rock", singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Purple Rock"]      = { id = 774, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["White Rock"]       = { id = 776, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Black Rock"]       = { id = 775, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Sulfur"]           = { id = 1108, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Iron Sand"]        = { id = 1155, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Bomb Ash"]         = { id = 928, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Bomb Arm"]         = { id = 17316, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Goblin Die"]       = { id = 568, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Demon Horn"]       = { id = 902, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Aht Urhgan Brass"] = { id = 2417, short = "Aht Urh. Brass", singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Orpiment"]         = { id = 2126, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Snapping Mole"]    = { id = 1984, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Troll Pauldron"]   = { id = 2160, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Troll Vambrace"]   = { id = 2161, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Moblin Mask"]      = { id = 1638, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Moblin Helm"]      = { id = 1625, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Moblin Mail"]      = { id = 1632, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Moblin Armor"]     = { id = 1631, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Plumbago"]         = { id = 2860, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Mine Gravel"]      = { id = 597, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
        },
        clamming =
        {
            ["Oxblood"]                  = { id = 1311, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 6, color = -3877684, soundFile = "" },
            ["Turtle Shell"]             = { id = 885, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 6, color = -3877684, soundFile = "" },
            ["High-Quality Crab Shell"]  = { id = 1193, short = "HQ Crab Shell", singlePrice = 0, stackPrice = 0, pz = 6, stackSize = 12, color = -3877684, soundFile = "" },
            ["Lacquer Tree Log"]         = { id = 1446, short = "Lacq. Tree Log", singlePrice = 0, stackPrice = 0, pz = 6, stackSize = 12, color = -3877684, soundFile = "" },
            ["Bibiki Urchin"]            = { id = 4318, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 6, color = -3877684, soundFile = "" },
            ["Titanictus Shell"]         = { id = 1586, short = "Titan. Shell", singlePrice = 0, stackPrice = 0, pz = 6, stackSize = 12, color = -3877684, soundFile = "" },
            ["Tropical Clam"]            = { id = 5124, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 20, color = -3877684, soundFile = "" },
            ["Elm Log"]                  = { id = 690, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 6, color = -3877684, soundFile = "" },
            ["Coral Fragment"]           = { id = 887, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 6, color = -3877684, soundFile = "" },
            ["Petrified Log"]            = { id = 703, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 6, color = -3877684, soundFile = "" },
            ["Maple Log"]                = { id = 691, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 6, color = -3877684, soundFile = "" },
            ["Pamamas"]                  = { id = 4468, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 6, color = -3877684, soundFile = "" },
            ["High-Quality Pugil Scale"] = { id = 3270, short = "HQ Pugil Scale", singlePrice = 0, stackPrice = 0, stackSize = 1, pz = 6, color = -3877684, soundFile = "" },
            ["Seashell"]                 = { id = 888, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 6, color = -3877684, soundFile = "" },
            ["Hobgoblin Bread"]          = { id = 4328, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 6, color = -3877684, soundFile = "" },
            ["Broken Willow Rod"]        = { id = 485, short = "Bkn. Willow Rod", singlePrice = 0, stackPrice = 0, stackSize = 1, pz = 6, color = -3877684, soundFile = "" },
            ["Goblin Armor"]             = { id = 510, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 6, color = -3877684, soundFile = "" },
            ["Elshimo Coconut"]          = { id = 5187, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 6, color = -3877684, soundFile = "" },
            ["Goblin Mail"]              = { id = 507, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 6, color = -3877684, soundFile = "" },
            ["Crab Shell"]               = { id = 881, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 6, color = -3877684, soundFile = "" },
            ["Hobgoblin Pie"]            = { id = 4325, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 6, color = -3877684, soundFile = "" },
            ["Rock Salt"]                = { id = 936, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 6, color = -3877684, soundFile = "" },
            ["Nebimonite"]               = { id = 4361, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 6, color = -3877684, soundFile = "" },
            ["Fish Scales"]              = { id = 864, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 6, color = -3877684, soundFile = "" },
            ["Shall Shell"]              = { id = 4484, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 6, color = -3877684, soundFile = "" },
            ["Pamtam Kelp"]              = { id = 624, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 6, color = -3877684, soundFile = "" },
            ["Igneous Rock"]             = { id = 1654, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 6, color = -3877684, soundFile = "" },
            ["Pebble"]                   = { id = 17296, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 99, pz = 7, color = -3877684, soundFile = "" },
            ["Jacknife"]                 = { id = 5123, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 11, color = -3877684, soundFile = "" },
            ["Bibiki Slug"]              = { id = 5122, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, pz = 3, color = -3877684, soundFile = "" },
        },
        fishing =
        {
           ["Abaia"]             = { id = 5476, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Ahtapot"]           = { id = 5455, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Alabaligi"]         = { id = 5461, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Armored Pisces"]    = { id = 4316, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Arrowwood Log"]     = { id = 688, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Bastore Bream"]     = { id = 4461, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Bastore Sardine"]   = { id = 4360, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Bastore Sweeper"]   = { id = 5473, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Betta"]             = { id = 5139, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Bhefhel Marlin"]    = { id = 4479, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Bibiki Urchin"]     = { id = 4318, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Bibikibo"]          = { id = 4314, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Black Eel"]         = { id = 4429, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Black Ghost"]       = { id = 5138, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Black Sole"]        = { id = 4384, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Bladefish"]         = { id = 4471, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Blindfish"]         = { id = 4313, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Bluetail"]          = { id = 4399, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Brass Loach"]       = { id = 5469, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Ca Cuong"]          = { id = 5474, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Caedarva Frog"]     = { id = 5465, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Cave Cherax"]       = { id = 4309, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Cheval Salmon"]     = { id = 4379, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Cobalt Jellyfish"]  = { id = 4443, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Cone Calamary"]     = { id = 5128, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Copper Frog"]       = { id = 4515, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Copper Ring"]       = { id = 13454, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Coral Butterfly"]   = { id = 4580, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Coral Fragment"]    = { id = 887, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Crayfish"]          = { id = 4472, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Crescent Fish"]     = { id = 4473, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Crystal Bass"]      = { id = 4528, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Damp Scroll"]       = { id = 1210, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Dark Bass"]         = { id = 4428, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Denizanasi"]        = { id = 5447, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Dil"]               = { id = 5457, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Elshimo Frog"]      = { id = 4290, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Elshimo Newt"]      = { id = 4579, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Emperor Fish"]      = { id = 4454, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Fat Greedie"]       = { id = 4501, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Fish Scale Shield"] = { id = 12316, short = "Fish Scale Shld.", singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Forest Carp"]       = { id = 4289, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Garpike"]           = { id = 5472, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Gavial Fish"]       = { id = 4477, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Gerrothorax"]       = { id = 5471, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Giant Catfish"]     = { id = 4469, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Giant Chirai"]      = { id = 4308, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Giant Donko"]       = { id = 4306, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Gigant Octopus"]    = { id = 5475, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Gigant Squid"]      = { id = 4474, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Gold Carp"]         = { id = 4427, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Gold Lobster"]      = { id = 4383, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Greedie"]           = { id = 4500, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Grimmonite"]        = { id = 4304, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Gugru Tuna"]        = { id = 4480, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Gugrusaurus"]       = { id = 5127, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Gurnard"]           = { id = 5132, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Hamsi"]             = { id = 5449, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Hydrogauge"]        = { id = 2341, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Icefish"]           = { id = 4470, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Istakoz"]           = { id = 5453, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Istavrit"]          = { id = 5136, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Istiridye"]         = { id = 5456, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Jungle Catfish"]    = { id = 4307, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Kalamar"]           = { id = 5448, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Kalkanbaligi"]      = { id = 5140, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Kaplumbaga"]        = { id = 5464, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Kayabaligi"]        = { id = 5460, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Kilicbaligi"]       = { id = 5451, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Lakerda"]           = { id = 5450, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Lamp Marimo"]       = { id = 2216, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Lik"]               = { id = 5129, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Lungfish"]          = { id = 4315, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Matsya"]            = { id = 5468, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Megalodon"]         = { id = 5467, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Mercanbaligi"]      = { id = 5454, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Moat Carp"]         = { id = 4401, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Moblin Mask"]       = { id = 1638, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Mola Mola"]         = { id = 5134, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Monke-Onke"]        = { id = 4462, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Moorish Idol"]      = { id = 5121, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Morinabaligi"]      = { id = 5462, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Muddy Siredon"]     = { id = 5126, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Mythril Dagger"]    = { id = 16451, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Mythril Sword"]     = { id = 16537, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Nebimonite"]        = { id = 4361, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Noble Lady"]        = { id = 4485, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Norg Shell"]        = { id = 1135, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Nosteau Herring"]   = { id = 4482, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Ogre Eel"]          = { id = 4481, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Pamtam Kelp"]       = { id = 624, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Phanauet Newt"]     = { id = 5125, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Pipira"]            = { id = 4464, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Pirarucu"]          = { id = 5470, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Pterygotus"]        = { id = 5133, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Quus"]              = { id = 4514, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Red Terrapin"]      = { id = 4402, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Rhinochimera"]      = { id = 5135, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Rusty Bucket"]      = { id = 90, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Rusty Cap"]         = { id = 12522, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Rusty Greatsword"]  = { id = 16606, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Rusty Leggings"]    = { id = 14117, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Rusty Pick"]        = { id = 16655, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Rusty Subligar"]    = { id = 14242, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Ryugu Titan"]       = { id = 4305, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Sandfish"]          = { id = 4291, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Sazanbaligi"]       = { id = 5459, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Sea Zombie"]        = { id = 4475, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Shall Shell"]       = { id = 4484, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Shining Trout"]     = { id = 4354, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Silver Ring"]       = { id = 13456, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Silver Shark"]      = { id = 4451, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Takitaro"]          = { id = 4463, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Tavnazian Goby"]    = { id = 5130, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Three-Eyed Fish"]   = { id = 4478, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Tiger Cod"]         = { id = 4483, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Tiny Goldfish"]     = { id = 4310, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Titanic Sawfish"]   = { id = 5120, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Titanictus"]        = { id = 4476, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Tricolored Carp"]   = { id = 4426, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Tricorn"]           = { id = 4319, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Trilobite"]         = { id = 4317, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Trumpet Shell"]     = { id = 5466, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Turnabaligi"]       = { id = 5137, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Uskumru"]           = { id = 5452, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Veydal Wrasse"]     = { id = 5141, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Vongola Clam"]      = { id = 5131, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Yayinbaligi"]       = { id = 5463, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Yellow Globe"]      = { id = 4403, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Yilanbaligi"]       = { id = 5458, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Zafmlug Bass"]      = { id = 4385, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Zebra Eel"]         = { id = 4288, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Bugbear Mask"]      = { id = 1624, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Adoulinian Kelp"]   = { id = 3965, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
           ["Ripped cap"]        = { id = 591, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
           ["Gil"]               = { id = nil, short = nil, singlePrice = nil, stackPrice = nil, stackSize = 1, color = -3877684, soundFile = "" },
           ["Monster"]           = { id = nil, short = nil, singlePrice = nil, stackPrice = nil, stackSize = 1, color = -3877684, soundFile = "" },
        },
        digging =
        {
            ["Acorn"]                     = { id = 4504, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Bone Chip"]                 = { id = 880, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Arrowwood Log"]             = { id = 688, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Holly Log"]                 = { id = 697, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["King Truffle"]              = { id = 4386, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Little Worm"]               = { id = 17396, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 99, color = -3877684, soundFile = "" },
            ["Maple Log"]                 = { id = 691, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Mistletoe"]                 = { id = 918, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Oak Log"]                   = { id = 699, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Scream Fungus"]             = { id = 4447, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Willow Log"]                = { id = 695, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Fire Crystal"]              = { id = 4096, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Ice Crystal"]               = { id = 4097, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Wind Crystal"]              = { id = 4098, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Earth Crystal"]             = { id = 4099, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Lightning Crystal"]         = { id = 4100, short = "Ltng. Crystal", singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Water Crystal"]             = { id = 4101, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Light Crystal"]             = { id = 4102, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Dark Crystal"]              = { id = 4103, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Fire Cluster"]              = { id = 4104, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Water Cluster"]             = { id = 4109, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Earth Cluster"]             = { id = 4107, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Wind Cluster"]              = { id = 4106, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Ice Cluster"]               = { id = 4105, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Lightning Cluster"]         = { id = 4108, short = "Ltng. Cluster", singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Light Cluster"]             = { id = 4110, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Dark Cluster"]              = { id = 4111, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Fire Ore"]                  = { id = 1255, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Earth Ore"]                 = { id = 1258, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Water Ore"]                 = { id = 1260, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Wind Ore"]                  = { id = 1257, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Ice Ore"]                   = { id = 1256, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Lightning Ore"]             = { id = 1259, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Light Ore"]                 = { id = 1261, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Dark Ore"]                  = { id = 1262, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Elm Log"]                   = { id = 690, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Lacquer Tree Log"]          = { id = 1446, short = "Lacq. Tree Log", singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Mahogany Log"]              = { id = 700, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Rosewood Log"]              = { id = 701, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Yew Log"]                   = { id = 696, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Bird Egg"]                  = { id = 4570, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Colored Egg"]               = { id = 4487, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Hard-boiled Egg"]           = { id = 4409, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Sairui-Ran"]                = { id = 1188, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 99, color = -3877684, soundFile = "" },
            ["Soft-boiled Egg"]           = { id = 4532, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Bird Feather"]              = { id = 847, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Coral Fragment"]            = { id = 887, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Giant Femur"]               = { id = 893, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Lugworm"]                   = { id = 17395, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 99, color = -3877684, soundFile = "" },
            ["Platinum Ore"]              = { id = 738, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Seashell"]                  = { id = 888, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Shall Shell"]               = { id = 4484, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Shell Bug"]                 = { id = 17397, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Tin Ore"]                   = { id = 641, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Turtle Shell"]              = { id = 885, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Black Chocobo Feather"]     = { id = 845, short = "Blk. Choco Feather", singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Giant Bird Plume"]          = { id = 843, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Phoenix Feather"]           = { id = 844, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Red Moko Grass"]            = { id = 1845, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Spider Web"]                = { id = 838, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Demon Horn"]                = { id = 902, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Demon Skull"]               = { id = 886, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Dragon Scales"]             = { id = 867, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Fish Scales"]               = { id = 864, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["High-Quality Pugil Scales"] = { id = 1587, short = "HQ Pugil Scales", singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Titanictus Shell"]          = { id = 1586, short = "Titan. Shell", singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Wyvern Scales"]             = { id = 866, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Adaman Ore"]                = { id = 646, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Ebony Log"]                 = { id = 702, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Moko Grass"]                = { id = 833, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Pebble"]                    = { id = 17296, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 99, color = -3877684, soundFile = "" },
            ["Pephredo Hive Chip"]        = { id = 2164, short = "Pep. Hive Chip", singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Pine Nuts"]                 = { id = 2213, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Aluminum Ore"]              = { id = 678, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Flint Stone"]               = { id = 768, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Gold Ore"]                  = { id = 737, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Kaolin"]                    = { id = 2475, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Orichalcum Ore"]            = { id = 739, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Colibri Feather"]           = { id = 2150, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Dried Marjoram"]            = { id = 622, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Lesser Chigoe"]             = { id = 2155, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Petrified Log"]             = { id = 703, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Darksteel Ore"]             = { id = 645, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Ash Log"]                   = { id = 698, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Chocobo Feather"]           = { id = 840, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Ronfaure Chestnut"]         = { id = 639, short = "Ron. Chestnut", singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Chestnut Log"]              = { id = 694, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Gysahl Greens"]             = { id = 4545, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Chamomile"]                 = { id = 636, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Ginger"]                    = { id = 617, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Vegetable Seeds"]           = { id = 573, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Fruit Seeds"]               = { id = 574, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Zinc Ore"]                  = { id = 642, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Pie Dough"]                 = { id = 616, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Napa"]                      = { id = 5235, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Yellow Ginseng"]            = { id = 2364, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Wildgrass Seeds"]           = { id = 2235, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Tree Cuttings"]             = { id = 1237, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Red Rock"]                  = { id = 769, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Yellow Rock"]               = { id = 771, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Blue Rock"]                 = { id = 770, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Green Rock"]                = { id = 772, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Translucent Rock"]          = { id = 773, short = "Trans. Rock", singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Purple Rock"]               = { id = 774, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["White Rock"]                = { id = 776, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Black Rock"]                = { id = 775, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Lizard Molt"]               = { id = 869, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Copper Ore"]                = { id = 640, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Iron Ore"]                  = { id = 643, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Red Jar"]                   = { id = 106, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 1, color = -3877684, soundFile = "" },
            ["Reishi Mushroom"]           = { id = 4449, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Beastcoin"]                 = { id = 656, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Gold Beastcoin"]            = { id = 748, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Mythril Beastcoin"]         = { id = 749, short = "Myth. Beastcoin", singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Silver Beastcoin"]          = { id = 750, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Insect Wing"]               = { id = 846, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Pugil Scales"]              = { id = 868, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Mythril Ore"]               = { id = 644, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Cactus Stems"]              = { id = 1236, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Rock Salt"]                 = { id = 936, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Grain Seeds"]               = { id = 575, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Giant Bird Feather"]        = { id = 842, short = "Gnt. Bird Feather", singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Coral Fungus"]              = { id = 4450, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Deathball"]                 = { id = 4566, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Puffball"]                  = { id = 4448, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Sage"]                      = { id = 638, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Danceshroom"]               = { id = 4375, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Sleepshroom"]               = { id = 4374, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Woozyshroom"]               = { id = 4373, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Silver Ore"]                = { id = 736, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Philosopher's Stone"]       = { id = 942, short = "Philos. Stone", singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Herb Seeds"]                = { id = 572, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Lauan Log"]                 = { id = 689, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Yagudo Feather"]            = { id = 841, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Saruta Cotton"]             = { id = 834, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Papaka Grass"]              = { id = 938, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Platinum Beastcoin"]        = { id = 751, short = "Plat. Beastcoin", singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Kopparnickel Ore"]          = { id = 1650, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Ancient Lumber"]            = { id = 720, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Cinnamon"]                  = { id = 628, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Rattan Lumber"]             = { id = 721, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Mushroom Locust"]           = { id = 1983, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Kazham Pineapple"]          = { id = 4432, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
            ["Dryad Root"]                = { id = 923, short = nil, singlePrice = 0, stackPrice = 0, stackSize = 12, color = -3877684, soundFile = "" },
        }
    },
    metrics = {}
}

return {
    defaultSettingsTemplate = defaultSettingsTemplate,
    stateTemplate = stateTemplate,
    metricsTemplate = metricsTemplate
}